@@ -9,13 +9,10 @@ import {
     TupleDataOfflineObserverService,
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
-    TupleSelector,
     TupleStorageFactoryService,
     VortexService,
-    VortexStatusService,
-    WebSqlFactoryService
+    VortexStatusService
 } from "@synerty/vortexjs"
-
 import {
     chunkedIndexActionProcessorName,
     chunkedIndexFilt,
